@@ -8,21 +8,21 @@ from graphql_jwt.decorators import login_required, user_passes_test, staff_membe
 # Standard/core python libraries
 # Our custom libraries
 from models_app.models import UserApp
-from .types import ExampleDjangoType
+from .types import ExampleDjangoUsersType
 # EXAMPLE QUERY GRAPHENE (Managed by SPRINGLABS_DJANGO)
 
 
-class ExampleDjangoQueries(object):
+class ExampleDjangoUsersQueries(object):
     # FIELDS
-    users = graphene.List(
-        ExampleDjangoType,
+    examples = graphene.List(
+        ExampleDjangoUsersType,
         client=graphene.Argument(graphene.ID, required=True),
         role=graphene.Argument(graphene.String, required=False),
         agent=graphene.Argument(graphene.ID, required=False),
         description='Obtain all users.'
     )
-    user = graphene.Field(
-        ExampleDjangoType,
+    example = graphene.Field(
+        ExampleDjangoUsersType,
         id=graphene.Argument(graphene.ID, required=True),
         description='Lookup a user by ID or pk.'
     )
@@ -30,7 +30,7 @@ class ExampleDjangoQueries(object):
     # RESOLVES
     @login_required
     @user_passes_test(lambda user: user.is_staff or len(user.groups.filter(name='Administrador')) > 0)
-    def resolve_users(self, info, **kwargs):
+    def resolve_examples(self, info, **kwargs):
         users = UserApp.objects.filter(client=kwargs['client'])
         result = []
         for user in users:
@@ -46,7 +46,7 @@ class ExampleDjangoQueries(object):
 
     @login_required
     @user_passes_test(lambda user: user.is_staff or len(user.groups.filter(name='Administrador')) > 0)
-    def resolve_user(self, info, **kwargs):
+    def resolve_example(self, info, **kwargs):
         if UserApp.objects.filter(pk=kwargs['id']).exists():
             objUserApp = UserApp.objects.get(pk=kwargs['id'])
             objUser = {
