@@ -9,7 +9,7 @@ from models_app.models import UserApp
 # EXAMPLE GRAPHENE ObjectType (Managed by SPRINGLABS_DJANGO)
 
 
-class ExampleDjangoType(graphene.ObjectType):
+class ExampleDjangoUsersType(graphene.ObjectType):
     id_user = graphene.ID(description="A unique int value identifying User",
         required=False)
     username = graphene.String(description="A unique string value identifying User",
