@@ -4,6 +4,7 @@ from zipfile import ZipFile
 import shutil
 import pkgutil
 import json
+from . import CONFIG_JSON, PROJECT_PACKAGE
 
 
 def appendContent(path, content, find=None, recursive=False):
@@ -22,7 +23,7 @@ def appendContent(path, content, find=None, recursive=False):
             OSError                             Error al escribir el contenido
     '''
     if not os.path.exists(path):
-        return f'El archivo {path} no existe', False
+        return f'File {path} does not exist', False
     if find == None:
         try:
             """ if not os.path.exists(path):
@@ -32,16 +33,16 @@ def appendContent(path, content, find=None, recursive=False):
             with open(path, "a") as f:
                 newContent = f'\n{content}'
                 f.write(newContent)
-            return f'Se actualizó correctamente el archivo: {path}', True
+            return f'The file "{path}" has been updated successfully.', True
         except Exception as exc:
-            return f'Error al escribir el contenido:{exc}', False
+            return f'Error writing content:{exc}', False
     else:
         if recursive == False:
             return notRecursiveModify(path, content, find, 'append')
         elif recursive == True:
             return recursiveModify(path, content, find, 'append')
 
-        return f'Valor no válido para el parametro recursive', False
+        return f'Invalid value for recursive parameter', False
 
 
 def replaceContent(path, content, start, end='--end', recursive=False):
@@ -59,14 +60,14 @@ def replaceContent(path, content, start, end='--end', recursive=False):
             OSError                             Error al escribir el contenido
     '''
     if not os.path.exists(path):
-        return f'El archivo {path} no existe', False
+        return f'File {path} does not exists', False
 
     starts = getRangeStr(path, start)
     ends = getRangeEnds(path, end)
     if ends == None or len(ends) == 0:
-        return f'Tu archivo no cuenta con delimitadores de fin: "{end}"', False
+        return f'The file does not have end delimiters: "{end}"', False
     if starts == None or len(starts) == 0:
-        return f'Tu archivo no cuenta con delimitadores de inicio: "{start}"', False
+        return f'The file does not have start delimiters: "{start}"', False
     textsReplace = []
     for idx, _ in enumerate(ends):
         if len(starts) <= idx or starts[idx][1] > ends[idx][0]:
@@ -74,7 +75,7 @@ def replaceContent(path, content, start, end='--end', recursive=False):
         textsReplace.append([starts[idx][1] + 1,  ends[idx][0] - 1])
     file = open(path).read()
     if len(textsReplace) == 0:
-        return f'Tu archivo tiene mal los delimitadores de inicio "{start}" y/o los deliminatores de fin "{end}" , favor de verificar.', False
+        return f'The file has wrong start delimiters "{start}" and/or end delimiters "{end}", please check', False
     if recursive == False:
         return notRecursiveModify(path, content, file[textsReplace[0][0]:textsReplace[0][1]], 'replace')
     elif recursive == True:
@@ -82,11 +83,11 @@ def replaceContent(path, content, start, end='--end', recursive=False):
             for text in textsReplace:
                 recursiveModify(
                     path, content, file[text[0]:text[1]], 'replace')
-            return f'Se actualizó correctamente el archivo: {path}', True
+            return f'File "{path}" was successfully updated', True
         except Exception as exc:
-            return f'Error al escribir el contenido: {exc}', False
+            return f'Error writing content: {exc}', False
 
-    return f'Valor no válido para el parametro recursive', False
+    return f'Invalid value for recursive parameter', False
 
 
 def findNReplace(path, content, find, recursive=False):
@@ -104,13 +105,13 @@ def findNReplace(path, content, find, recursive=False):
             OSError                             Error al escribir el contenido
     '''
     if not os.path.exists(path):
-        return f'El archivo {path} no existe', False
+        return f'File {path} does not exists', False
     if recursive == False:
         return notRecursiveModify(path, content, find, 'replace')
     elif recursive == True:
         return recursiveModify(path, content, find, 'replace')
 
-    return f'Valor no válido para el parametro recursive', False
+    return f'Invalid value for recursive parameter', False
 
 
 def findNDelete(path, find, recursive=False):
@@ -127,13 +128,13 @@ def findNDelete(path, find, recursive=False):
             OSError                             Error al escribir el contenido
     '''
     if not os.path.exists(path):
-        return f'El archivo {path} no existe', False
+        return f'File {path} does not exists', False
     if recursive == False:
         return findNReplace(path, '', find)
     elif recursive == True:
         return findNReplace(path, '', find, recursive=True)
 
-    return f'Valor no válido para el parametro recursive', False
+    return f'Invalid value for recursive parameter', False
 
 
 def deleteContent(path, start, end='--end', recursive=False):
@@ -150,13 +151,13 @@ def deleteContent(path, start, end='--end', recursive=False):
             OSError                             Error al escribir el contenido
     '''
     if not os.path.exists(path):
-        return f'El archivo no existe', False
+        return f'The file does not exists', False
     if recursive == False:
         return replaceContent(path, '', start, end)
     elif recursive == True:
         return replaceContent(path, '', start, end, recursive=True)
 
-    return f'Valor no válido para el parametro recursive', False
+    return f'Invalid value for recursive parameter', False
 
 
 def notRecursiveModify(path, content, find, type):
@@ -197,21 +198,21 @@ def notRecursiveModify(path, content, find, type):
         matchFound = True
         break
     if matchFound == False:
-        return f'No se encontraron coincidencias de "{find}"', False
+        return f'No matches found with "{find}"', False
     if type == 'append':
         newContent = f'{file[: m.end()]}  \n{content} \n{file[m.end() + 1:]}'
     elif type == 'replace':
         newContent = f'{file[: m.start()]}{content}{file[m.end():]}'
     else:
-        return f'Tipo de remplazo no válido', False
+        return f'Invalid replacement type', False
     try:
         '''with open(f'{path}.bak', "w") as f:
                 f.write(open(path).read())'''
         with open(path, "w") as f:
             f.write(newContent)
-        return f'Se actualizó correctamente el archivo: {path}', True
+        return f'File "{path}" was successfully updated', True
     except Exception as exc:
-        return f'Error al escribir el contenido: {exc}', False
+        return f'Error writing content: {exc}', False
 
 
 def recursiveModify(path, content, find, type):
@@ -233,16 +234,16 @@ def recursiveModify(path, content, find, type):
     elif type == 'replace':
         newContent = content
     else:
-        return f'Tipo de remplazo no válido', False
+        return f'Invalid replacement type', False
     try:
         file = open(path).read()
         '''with open(f'{path}.bak', "w") as f:
 			f.write(open(path).read())'''
         with open(path, "w") as f:
             f.write(file.replace(find, newContent))
-        return f'Se actualizó correctamente el archivo: {path}', True
+        return f'File "{path}" was successfully updated', True
     except Exception as exc:
-        return f'Error al escribir el contenido: {exc}', False
+        return f'Error writing content: {exc}', False
 
 
 def getRangeStr(path, find):
@@ -301,18 +302,41 @@ def getRangeEnds(path, find):
 
 
 def generateBackup(project_name, path=os.getcwd()):
+    """
+        Función que genera un respaldo del proyecto 
+
+        Función encargada de generar un respaldo del proyecto antes de realizar alguna
+        acción, se genera un zip con el nombre del proyecto por si algo llega a fallar
+        revertir los cambios 
+        
+        Parametros:
+            project_name (String): Nombre del proyecto a generar respaldo
+            path (String): Ruta donde se encuentra el proyecto a respaldar 
+        Retorno:
+            message,result (Tuple): Mensaje[String] y result[Boolean]
+
+    """
     oldPath = path
     os.chdir("..")
-    # TEST LOCAL
-    #shutil.make_archive(project_name, 'zip', base_dir="springlabs-django-cli")
-    # PRODUCTIVE
     shutil.make_archive(project_name, 'zip', base_dir=project_name)
     os.chdir(oldPath)
     return "OK", True
     
 
-
 def reverseChanges(project_name, path=os.getcwd()):
+    """
+        Función que revierte los cambios de una acción 
+
+        Función encargada de revertir los cambios de una acción, hace que se haga un unzip
+        del respaldo realizado antes de la acción y poder eliminar el contenido con errores 
+        
+        Parametros:
+            project_name (String): Nombre del proyecto a revertir cambios
+            path (String): Ruta donde se encuentra el proyecto a revertir 
+        Retorno:
+            message,result (Tuple): Mensaje[String] y result[Boolean]
+
+    """
     try:
         oldPath = path
         os.chdir("..")
@@ -326,6 +350,28 @@ def reverseChanges(project_name, path=os.getcwd()):
         return str(e), False
 
 
+def deleteBackup(project_name, path=os.getcwd()):
+    """
+        Función que elimina el respaldo de un proyecto 
+
+        Función encargada de eliminar el respaldo de un proyecto al terminar una acción 
+        
+        Parametros:
+            project_name (String): Nombre del proyecto que se desea eliminar respaldo
+            path (String): Ruta donde se encuentra el proyecto que se desea eliminar respaldo
+        Retorno:
+            message,result (Tuple): Mensaje[String] y result[Boolean]
+
+    """
+    try:
+        oldPath = os.getcwd()
+        os.chdir("..")
+        os.remove(project_name + ".zip")
+        os.chdir(oldPath)
+        return "OK", True
+    except Exception as e:
+        return str(e), False
+
 def modifyFilesNewVersion(version, project_name, old_versions):
     """
         Función que modifica archivos para agregar nueva versión
@@ -446,7 +492,6 @@ def createDirectoriesNewVersion(version, project_name, old_versions):
     errors = []
     
     # Crear carpeta API nueva versión con archivos
-    primary_package = "springlabs_django"
     os.chdir("api")
     new_version = f"v{version}"
     os.mkdir(new_version)
@@ -458,40 +503,40 @@ def createDirectoriesNewVersion(version, project_name, old_versions):
 
     # Obtiene contenido de core/new_version/api/baseUrls.py
     try:
-        template_urls_py = pkgutil.get_data(primary_package, base_urls_py).decode('utf-8')
+        template_urls_py = pkgutil.get_data(PROJECT_PACKAGE, base_urls_py).decode('utf-8')
         template_urls_py = template_urls_py.replace("name_version", new_version)
     except:
-        message = f"Ocurrió un error interno en core/{new_version}/api/baseUrls.py"
+        message = f"An internal error occurred in core/{new_version}/api/baseUrls.py"
         errors.append([message, True])
 
     # Obtiene contenido de core/new_version/api/basePublicUrls.py
     try:
-        template_public_urls_py = pkgutil.get_data(primary_package, base_public_urls_py).decode('utf-8')
+        template_public_urls_py = pkgutil.get_data(PROJECT_PACKAGE, base_public_urls_py).decode('utf-8')
         template_public_urls_py = template_public_urls_py.replace("name_version", new_version)
     except:
-        message = f"Ocurrió un error interno en core/{new_version}/api/basePublicUrls.py"
+        message = f"An internal error occurred in core/{new_version}/api/basePublicUrls.py"
         errors.append([message, True])
 
     # Obtiene contenido de core/new_version/api/basePrivateUrls.py
     try:
-        template_private_urls_py = pkgutil.get_data(primary_package, base_private_urls_py).decode('utf-8')
+        template_private_urls_py = pkgutil.get_data(PROJECT_PACKAGE, base_private_urls_py).decode('utf-8')
         template_private_urls_py = template_private_urls_py.replace("name_version", new_version)
     except:
-        message = f"Ocurrió un error interno en core/{new_version}/api/basePrivateUrls.py"
+        message = f"An internal error occurred in core/{new_version}/api/basePrivateUrls.py"
         errors.append([message, True])
 
     # Obtiene contenido de core/new_version/api/baseSerializers.py
     try:
-        template_serializers_py = pkgutil.get_data(primary_package, base_serializers_py).decode('utf-8')
+        template_serializers_py = pkgutil.get_data(PROJECT_PACKAGE, base_serializers_py).decode('utf-8')
     except:
-        message = f"Ocurrió un error interno en core/{new_version}/api/baseSerializers.py"
+        message = f"An internal error occurred in core/{new_version}/api/baseSerializers.py"
         errors.append([message, True])
 
     # Obtiene contenido de core/new_version/api/baseViews.py
     try:
-        template_views_py = pkgutil.get_data(primary_package, base_views_py).decode('utf-8')
+        template_views_py = pkgutil.get_data(PROJECT_PACKAGE, base_views_py).decode('utf-8')
     except:
-        message = f"Ocurrió un error interno en core/{new_version}/api/baseViews.py"
+        message = f"An internal error occurred in core/{new_version}/api/baseViews.py"
         errors.append([message, True])
 
     # Escribe contenido base en archivo api/new_version/urls.py
@@ -527,32 +572,32 @@ def createDirectoriesNewVersion(version, project_name, old_versions):
 
     # Obtiene contenido de core/new_version/graphql_api/baseUrls.py
     try:
-        template_urls_py = pkgutil.get_data(primary_package, base_urls_py).decode('utf-8')
+        template_urls_py = pkgutil.get_data(PROJECT_PACKAGE, base_urls_py).decode('utf-8')
         template_urls_py = template_urls_py.replace("name_version", new_version)
     except:
-        message = f"Ocurrió un error interno en core/{new_version}/graphql_api/baseUrls.py"
+        message = f"An internal error occurred in core/{new_version}/graphql_api/baseUrls.py"
         errors.append([message, True])
 
     # Obtiene contenido de core/new_version/graphql_api/baseApi.py
     try:
-        template_api_py = pkgutil.get_data(primary_package, base_api_py).decode('utf-8')
+        template_api_py = pkgutil.get_data(PROJECT_PACKAGE, base_api_py).decode('utf-8')
     except:
-        message = f"Ocurrió un error interno en core/{new_version}/graphql_api/baseApi.py"
+        message = f"An internal error occurred in core/{new_version}/graphql_api/baseApi.py"
         errors.append([message, True])
 
 
     # Obtiene contenido de core/new_version/graphql_api/baseSchema.py
     try:
-        template_schema_py = pkgutil.get_data(primary_package, base_schema_py).decode('utf-8')
+        template_schema_py = pkgutil.get_data(PROJECT_PACKAGE, base_schema_py).decode('utf-8')
     except:
-        message = f"Ocurrió un error interno en core/{new_version}/graphql_api/baseSchema.py"
+        message = f"An internal error occurred in core/{new_version}/graphql_api/baseSchema.py"
         errors.append([message, True])
 
     # Obtiene contenido de core/new_version/graphql_api/baseTypes.py
     try:
-        template_types_py = pkgutil.get_data(primary_package, base_types_py).decode('utf-8')
+        template_types_py = pkgutil.get_data(PROJECT_PACKAGE, base_types_py).decode('utf-8')
     except:
-        message = f"Ocurrió un error interno en core/{new_version}/graphql_api/baseTypes.py"
+        message = f"An internal error occurred in core/{new_version}/graphql_api/baseTypes.py"
         errors.append([message, True])
 
     # Escribe contenido base en archivo graphql_api/new_version/urls.py
@@ -589,30 +634,30 @@ def createDirectoriesNewVersion(version, project_name, old_versions):
 
     # Obtiene contenido de core/new_version/tests/baseTestApis.py
     try:
-        template_test_apis_py = pkgutil.get_data(primary_package, base_test_apis_py).decode('utf-8')
+        template_test_apis_py = pkgutil.get_data(PROJECT_PACKAGE, base_test_apis_py).decode('utf-8')
     except:
-        message = f"Ocurrió un error interno en core/{new_version}/tests/baseTestApis.py"
+        message = f"An internal error occurred in core/{new_version}/tests/baseTestApis.py"
         errors.append([message, True])
     
     # Obtiene contenido de core/new_version/tests/baseTestFunctions1.py
     try:
-        template_test_functions1_py = pkgutil.get_data(primary_package, base_test_functions1_py).decode('utf-8')
+        template_test_functions1_py = pkgutil.get_data(PROJECT_PACKAGE, base_test_functions1_py).decode('utf-8')
     except:
-        message = f"Ocurrió un error interno en core/{new_version}/tests/baseTestFunctions1.py"
+        message = f"An internal error occurred in core/{new_version}/tests/baseTestFunctions1.py"
         errors.append([message, True])
     
     # Obtiene contenido de core/new_version/tests/baseTestSerializers.py
     try:
-        template_test_serializers_py = pkgutil.get_data(primary_package, base_test_serializers_py).decode('utf-8')
+        template_test_serializers_py = pkgutil.get_data(PROJECT_PACKAGE, base_test_serializers_py).decode('utf-8')
     except:
-        message = f"Ocurrió un error interno en core/{new_version}/tests/baseTestSerializers.py"
+        message = f"An internal error occurred in core/{new_version}/tests/baseTestSerializers.py"
         errors.append([message, True])
     
     # Obtiene contenido de core/new_version/tests/baseTestFunctions.py
     try:
-        template_test_functions_py = pkgutil.get_data(primary_package, base_test_functions_py).decode('utf-8')
+        template_test_functions_py = pkgutil.get_data(PROJECT_PACKAGE, base_test_functions_py).decode('utf-8')
     except:
-        message = f"Ocurrió un error interno en core/{new_version}/tests/baseTestFunctions.py"
+        message = f"An internal error occurred in core/{new_version}/tests/baseTestFunctions.py"
         errors.append([message, True])
     
 
@@ -659,7 +704,6 @@ def modifyFilesNewAPI(version,group,name,http_verb,type_api,url,availability,pro
             message,result  [Tuple]     Mensaje[String] y result[Boolean]
     """
     errors = []
-    primary_package = "springlabs_django"
     
     # Obtener variables dependientes del HTTP_VERB
     if http_verb == "POST":
@@ -690,18 +734,18 @@ def modifyFilesNewAPI(version,group,name,http_verb,type_api,url,availability,pro
     base_serializers_py = f"/core/new_api/api/{base_serializers}"
     # Obtiene contenido de /core/new_api/api/{base_views}
     try:
-        template_views_py = pkgutil.get_data(primary_package, base_views_py).decode('utf-8')
+        template_views_py = pkgutil.get_data(PROJECT_PACKAGE, base_views_py).decode('utf-8')
         template_views_py = template_views_py.replace("API_NAME", name.capitalize())
     except:
-        message = f"Ocurrió un error interno en /core/new_api/api/{base_views}"
+        message = f"An internal error occurred in /core/new_api/api/{base_views}"
         errors.append([message, True])
     
     # Obtiene contenido de /core/new_api/api/{base_serializers}
     try:
-        template_serializers_py = pkgutil.get_data(primary_package, base_serializers_py).decode('utf-8')
+        template_serializers_py = pkgutil.get_data(PROJECT_PACKAGE, base_serializers_py).decode('utf-8')
         template_serializers_py = template_serializers_py.replace("API_NAME", name.capitalize())
     except:
-        message = f"Ocurrió un error interno en /core/new_api/api/{base_serializers}"
+        message = f"An internal error occurred in /core/new_api/api/{base_serializers}"
         errors.append([message, True])
     
     # Escribe en archivo views.py
@@ -752,17 +796,15 @@ def modifyFilesNewGraph(version,group,name,type_graph,project_name):
             message,result  [Tuple]     Mensaje[String] y result[Boolean]
     """
     errors = []
-    primary_package = "springlabs_django"
-    SPRINGLABS_DJANGO_JSON = "springlabs_django.json"
     
 
     graph_version = version
     group_graph = group
     try:
-        with open(SPRINGLABS_DJANGO_JSON) as file:
+        with open(CONFIG_JSON) as file:
             data = json.load(file)
     except:
-        message = f"Ocurrió un problema interno al leer archivo ({SPRINGLABS_DJANGO_JSON})"
+        message = f"An internal error occurred while reading file ({CONFIG_JSON})"
         return message, False
     else:
         versions_detail = data['versions_detail']
@@ -805,18 +847,18 @@ def modifyFilesNewGraph(version,group,name,type_graph,project_name):
 
     # Obtiene contenido de /core/new_graph/graph/{base_schema}
     try:
-        template_schema_py = pkgutil.get_data(primary_package, base_schema_py).decode('utf-8')
+        template_schema_py = pkgutil.get_data(PROJECT_PACKAGE, base_schema_py).decode('utf-8')
         template_schema_py = template_schema_py.replace("GRAPH_NAME", name.capitalize())
     except:
-        message = f"Ocurrió un error interno en /core/new_graph/graph/{base_schema}"
+        message = f"An internal error occurred in /core/new_graph/graph/{base_schema}"
         errors.append([message, True])
     
     # Obtiene contenido de /core/new_graph/graph/{base_types}
     try:
-        template_types_py = pkgutil.get_data(primary_package, base_types_py).decode('utf-8')
+        template_types_py = pkgutil.get_data(PROJECT_PACKAGE, base_types_py).decode('utf-8')
         template_types_py = template_types_py.replace("GRAPH_NAME", name.capitalize())
     except:
-        message = f"Ocurrió un error interno en /core/new_graph/graph/{base_types}"
+        message = f"An internal error occurred in /core/new_graph/graph/{base_types}"
         errors.append([message, True])
     
     # Obtiene texto a buscar de import en schema.py y api.py
@@ -918,10 +960,10 @@ def modifyFilesNewGraph(version,group,name,type_graph,project_name):
                     new_import_api = new_import_api+f", {old_graph.capitalize()}Queries"
         index_graph_example_django = False
         try:
-            with open(SPRINGLABS_DJANGO_JSON) as file:
+            with open(CONFIG_JSON) as file:
                 data = json.load(file)
         except:
-            message = f"Ocurrio un error interno al actualizar archivo {SPRINGLABS_DJANGO_JSON}"
+            message = f"An internal error occurred while updating file {CONFIG_JSON}"
             errors.append([message, True])
         else:
             versions_detail = data['versions_detail']
@@ -949,10 +991,10 @@ def modifyFilesNewGraph(version,group,name,type_graph,project_name):
                 data['versions_detail'][index_version]['graph_list'][index_replace_example] = f"{name.capitalize()}Queries"
                 data['versions_detail'][index_version]['groups_detail'][index_groups]['graph'].pop(index_graph)
             try:
-                with open(SPRINGLABS_DJANGO_JSON, "w") as file:
+                with open(CONFIG_JSON, "w") as file:
                     file.write(json.dumps(data))
             except:
-                message = f"Ocurrio un error interno al actualizar archivo {SPRINGLABS_DJANGO_JSON}"
+                message = f"An internal error occurred while updating file {CONFIG_JSON}"
                 errors.append([message, True])
     else:
         new_import_schema = find_import_schema + f", {name.capitalize()}Type"
@@ -960,18 +1002,18 @@ def modifyFilesNewGraph(version,group,name,type_graph,project_name):
         new_query_api = base_new_query_api + f", {name.capitalize()}Queries"
         # Modifica graph_list
         try:
-            with open(SPRINGLABS_DJANGO_JSON) as file:
+            with open(CONFIG_JSON) as file:
                 data = json.load(file)
         except:
-            message = f"Ocurrio un error interno al actualizar archivo {SPRINGLABS_DJANGO_JSON}"
+            message = f"An internal error occurred while updating file {CONFIG_JSON}"
             errors.append([message, True])
         else:
             data['versions_detail'][index_version_modify]['graph_list'].append(f"{name.capitalize()}Queries")
             try:
-                with open(SPRINGLABS_DJANGO_JSON, "w") as file:
+                with open(CONFIG_JSON, "w") as file:
                     file.write(json.dumps(data))
             except:
-                message = f"Ocurrio un error interno al actualizar archivo {SPRINGLABS_DJANGO_JSON}"
+                message = f"An internal error occurred while updating file {CONFIG_JSON}"
                 errors.append([message, True])
         
         
@@ -1017,6 +1059,22 @@ def modifyFilesNewGraph(version,group,name,type_graph,project_name):
     return "OK", True
 
 def modifyFilesNewGroup(version, group,project_name):
+    """
+        Función encargada de modificar archivos para un nuevo grupo en django
+
+        Función encargada de modificar los archivos necesarios para crear un nuevo grupo
+        en el proyecto django.
+
+        Parámetros:
+            version         [String]    Versión donde se creará el grupo
+            group           [String]    Nombre del grupo
+            
+        Retorno:
+            message,result  [Tuple]     Mensaje[String] y result[Boolean]
+        Exceptions:
+            OSError                     Error al abrir o escribir archivos
+
+    """
     errors = []
     # Crear version en project_name/urls.py
     # Importar public versions de nueva versión
@@ -1083,10 +1141,10 @@ def modifyFilesNewGroup(version, group,project_name):
         errors.append([message, True])
 
     try:
-        with open('springlabs_django.json') as file:
+        with open(CONFIG_JSON) as file:
             data = json.load(file)
     except:
-        message = "Ocurrió un problema interno al leer archivo (springlabs_django.json)"
+        message = F"An internal error occurred while reading file ({CONFIG_JSON})"
         return message, False
 
     versions_detail=data["versions_detail"]
@@ -1110,7 +1168,7 @@ def modifyFilesNewGroup(version, group,project_name):
             errors.append([message, True])
 
     else:
-        message = "Ocurrió un problema interno, al leer archivo (springlabs_django.json)"
+        message = F"An internal error occurred while reading file ({CONFIG_JSON})"
         return message, False
 
     for error in errors:
@@ -1120,8 +1178,23 @@ def modifyFilesNewGroup(version, group,project_name):
     return "OK", True
 
 def createDirectoriesNewGroup(version, group, project_name):
+    """
+        Función que modifica directorios para agregar nuevo grupo
+
+        Función que modifica los directorios de Django y sus archivos dentro 
+        en los que se tiene que agregar el nuevo grupo
+
+        Parámetros:
+                version         [String]    Versión donde se creará el grupo
+                group           [String]    Nombre del grupo
+                project_name    [String]    Nombre del proyecto
+                
+        Retorno:
+                message,result  [Tuple]     Mensaje[String] y result[Boolean]
+        Exceptions:
+                OSError                     Error al abrir o escribir archivos
+    """
     errors = []
-    primary_package = "springlabs_django"
     os.chdir(f"api/v{version}")
     os.mkdir(group)
 
@@ -1130,16 +1203,16 @@ def createDirectoriesNewGroup(version, group, project_name):
     
     # Obtiene contenido de core/new_version/api/baseSerializers.py
     try:
-        template_serializers_py = pkgutil.get_data(primary_package, base_serializers_py).decode('utf-8')
+        template_serializers_py = pkgutil.get_data(PROJECT_PACKAGE, base_serializers_py).decode('utf-8')
     except:
-        message = f"Ocurrió un error interno en core/new_version/api/baseSerializers.py"
+        message = f"An internal error occurred in core/new_version/api/baseSerializers.py"
         errors.append([message, True])
 
     # Obtiene contenido de core/new_version/api/baseViews.py
     try:
-        template_views_py = pkgutil.get_data(primary_package, base_views_py).decode('utf-8')
+        template_views_py = pkgutil.get_data(PROJECT_PACKAGE, base_views_py).decode('utf-8')
     except:
-        message = f"Ocurrió un error interno en core/new_version/api/baseViews.py"
+        message = f"An internal error occurred in core/new_version/api/baseViews.py"
         errors.append([message, True])
 
     # Escribe contenido base en archivo api/new_version/users/serializers.py
@@ -1160,18 +1233,18 @@ def createDirectoriesNewGroup(version, group, project_name):
 
     # Obtiene contenido de core/new_version/graphql_api/baseSchema.py
     try:
-        template_schema_py = pkgutil.get_data(primary_package, base_schema_py).decode('utf-8')
+        template_schema_py = pkgutil.get_data(PROJECT_PACKAGE, base_schema_py).decode('utf-8')
         template_schema_py = template_schema_py.replace("GRAPH_NAME", changename)
     except:
-        message = f"Ocurrió un error interno en core/new_version/graphql_api/baseSchema.py"
+        message = f"An internal error occurred in core/new_version/graphql_api/baseSchema.py"
         errors.append([message, True])
 
     # Obtiene contenido de core/new_version/graphql_api/baseTypes.py
     try:
-        template_types_py = pkgutil.get_data(primary_package, base_types_py).decode('utf-8')
+        template_types_py = pkgutil.get_data(PROJECT_PACKAGE, base_types_py).decode('utf-8')
         template_types_py = template_types_py.replace("GRAPH_NAME", changename)
     except:
-        message = f"Ocurrió un error interno en core/new_version/graphql_api/baseTypes.py"
+        message = f"An internal error occurred in core/new_version/graphql_api/baseTypes.py"
         errors.append([message, True])
 
      # Escribe contenido base en archivo graphql_api/new_version/users/schema.py
