@@ -18,9 +18,12 @@ from .primary_functions import (
     modifyFilesNewAPI,
     modifyFilesNewGraph,
     modifyFilesNewGroup,
-    createDirectoriesNewGroup
+    createDirectoriesNewGroup,
+    deleteBackup
 )
+from . import PROJECT_PACKAGE, CONFIG_JSON, logging
 
+global_error="Sorry, an internal error occurred"
 def createVersion(version, project_name, old_versions):
     """
         Función encargada de crear nueva version en proyecto django
@@ -34,9 +37,10 @@ def createVersion(version, project_name, old_versions):
     """
     message, result = generateBackup(project_name=project_name)
     if result == False:
-        message = "Ocurrió un error interno al crear respaldo"
-        return message, False
-
+        message = "An internal error occurred while creating backup"
+        logging.error(message)
+        return global_error, False
+    
     errors = []
     # Modifica archivos para nueva versión
     message, result = modifyFilesNewVersion(version=version,
@@ -45,7 +49,8 @@ def createVersion(version, project_name, old_versions):
     
     # Si falla al escribir archivos se agrega a arreglo
     if result == False:
-        errors.append([message, True])
+        logging.error(message)
+        errors.append([global_error, True])
     
     # Crea directorios y archivos dentro para nueva versión
     message, result = createDirectoriesNewVersion(version=version,
@@ -54,13 +59,15 @@ def createVersion(version, project_name, old_versions):
     
     # Si falla al modificar directorios se agrega a arreglo
     if result == False:
-        errors.append([message, True])
+        logging.error(message)
+        errors.append([global_error, True])
     try:
-        with open('springlabs_django.json') as file:
+        with open(CONFIG_JSON) as file:
             data = json.load(file)
     except:
-        message = "Ocurrio un error interno al actualizar archivo springlabs_django.json"
-        errors.append([message, True])
+        message = f"An internal error occurred while creating backup {CONFIG_JSON}"
+        logging.error(message)
+        errors.append([global_error, True])
     else:
         objVersionDetail = {
             "version": version,
@@ -82,11 +89,12 @@ def createVersion(version, project_name, old_versions):
         data["versions"].append(version)
         data['versions_detail'].append(objVersionDetail)
         try:
-            with open("springlabs_django.json", "w") as file:
+            with open(CONFIG_JSON, "w") as file:
                 file.write(json.dumps(data))
         except:
-            message = "Ocurrio un error interno al actualizar archivo springlabs_django.json"
-            errors.append([message, True])
+            message = f"An internal error occurred while updating the file {CONFIG_JSON}"
+            logging.error(message)
+            errors.append([global_error, True])
 
     for error in errors:
         if error[1] == True:
@@ -95,9 +103,7 @@ def createVersion(version, project_name, old_versions):
             os.remove(project_name + ".zip")
             os.chdir(project_name)
             return error[0], False
-    
-
-
+    deleteBackup(project_name=project_name)
     return "OK", True
 
 def createAPI(version,group,name,http_verb,type_api,url,availability,project_name):
@@ -121,8 +127,9 @@ def createAPI(version,group,name,http_verb,type_api,url,availability,project_nam
     # Generar respaldo de proyecto
     message, result = generateBackup(project_name=project_name)
     if result == False:
-        message = "Ocurrió un error interno al crear respaldo"
-        return message, False
+        message = "An internal error occurred while creating backup"
+        logging.error(message)
+        return global_error, False
 
     errors = []
 
@@ -138,15 +145,17 @@ def createAPI(version,group,name,http_verb,type_api,url,availability,project_nam
     
     # Si falla al modificar directorios se agrega a arreglo
     if result == False:
-        errors.append([message, True])
+        logging.error(message)
+        errors.append([global_error, True])
 
 
     try:
-        with open('springlabs_django.json') as file:
+        with open(CONFIG_JSON) as file:
             data = json.load(file)
     except:
-        message = "Ocurrio un error interno al actualizar archivo springlabs_django.json"
-        errors.append([message, True])
+        message = f"An internal error occurred while updating the file {CONFIG_JSON}"
+        logging.error(message)
+        errors.append([global_error, True])
     else:
         objApis = {
             "api_name": name,
@@ -167,11 +176,12 @@ def createAPI(version,group,name,http_verb,type_api,url,availability,project_nam
                     if group == group_detail['group']:
                         data['versions_detail'][index_versions]['groups_detail'][index_groups]['apis'].append(objApis)
         try:
-            with open("springlabs_django.json", "w") as file:
+            with open(CONFIG_JSON, "w") as file:
                 file.write(json.dumps(data))
         except:
-            message = "Ocurrio un error interno al actualizar archivo springlabs_django.json"
-            errors.append([message, True])
+            message = f"An internal error occurred while updating the file {CONFIG_JSON}"
+            logging.error(message)
+            errors.append([global_error, True])
     # Si algo sale mal revertir los cambios y eliminar respaldo
     for error in errors:
         if error[1] == True:
@@ -180,7 +190,7 @@ def createAPI(version,group,name,http_verb,type_api,url,availability,project_nam
             os.remove(project_name + ".zip")
             os.chdir(project_name)
             return error[0], False
-
+    deleteBackup(project_name=project_name)
     return "OK", True
 
 def createGraph(version,group,name,type_graph,project_name):
@@ -202,8 +212,9 @@ def createGraph(version,group,name,type_graph,project_name):
     # Generar respaldo de proyecto
     message, result = generateBackup(project_name=project_name)
     if result == False:
-        message = "Ocurrió un error interno al crear respaldo"
-        return message, False
+        message = "An internal error occurred while creating backup"
+        logging.error(message)
+        return global_error, False
 
     errors = []
 
@@ -216,15 +227,17 @@ def createGraph(version,group,name,type_graph,project_name):
     
     # Si falla al modificar directorios se agrega a arreglo
     if result == False:
-        errors.append([message, True])
+        logging.error(message)
+        errors.append([global_error, True])
 
 
     try:
-        with open('springlabs_django.json') as file:
+        with open(CONFIG_JSON) as file:
             data = json.load(file)
     except:
-        message = "Ocurrio un error interno al actualizar archivo springlabs_django.json"
-        errors.append([message, True])
+        message = f"An internal error occurred while updating the file {CONFIG_JSON}"
+        logging.error(message)
+        errors.append([global_error, True])
     else:
         objGraph = {
             "graph_name": name,
@@ -242,11 +255,12 @@ def createGraph(version,group,name,type_graph,project_name):
                     if group == group_detail['group']:
                         data['versions_detail'][index_versions]['groups_detail'][index_groups]['graph'].append(objGraph)
         try:
-            with open("springlabs_django.json", "w") as file:
+            with open(CONFIG_JSON, "w") as file:
                 file.write(json.dumps(data))
         except:
-            message = "Ocurrio un error interno al actualizar archivo springlabs_django.json"
-            errors.append([message, True])
+            message = f"An internal error occurred while updating the file {CONFIG_JSON}"
+            logging.error(message)
+            errors.append([global_error, True])
     # Si algo sale mal revertir los cambios y eliminar respaldo
     for error in errors:
         if error[1] == True:
@@ -255,45 +269,75 @@ def createGraph(version,group,name,type_graph,project_name):
             os.remove(project_name + ".zip")
             os.chdir(project_name)
             return error[0], False
-    
+    deleteBackup(project_name=project_name)
     return "OK", True
 
 def getVersions():
+    """
+        Función que obtiene las versiones existentes del proyecto.
+
+        Esta función abre el archivo springlabs_json y obtiene las versiones
+        que existen en el proyecto
+
+        Retorno:
+            version     [Array]       Lista de versiones existentes
+        Exceptions:
+            OSError                   Error al abrir el archivo json
+    """
     try:
-        with open("springlabs_django.json", "r") as file:
+        with open(CONFIG_JSON, "r") as file:
             data = json.load(file)
         versions = data["versions"]
     except:
+        message="An error occurred while opening file 'springlabs_django.json'"
+        logging.error(message)
         versions=["1"]
     return versions
 
 def createGroup(version, group, project_name):
+    """
+        Función encargada de crear nuevo grupo en proyecto django
+
+        Parámetros:
+            version         [String]    Versión donde se creará el grupo
+            group           [String]    Grupo donde se creará el grupo
+            project_name    [String]    Nombre del proyecto
+        Retorno:
+            message,result  [Tuple]     Mensaje[String] y result[Boolean]
+        Excepciones:
+            OSError                     Error al abrir archivos
+
+    """
 
     # Generar respaldo de proyecto
     message, result = generateBackup(project_name=project_name)
     if result == False:
-        message = "Ocurrió un error interno al crear respaldo"
-        return message, False
+        message = "An internal error occurred while creating backup"
+        logging.error(message)
+        return global_error, False
     
     errors=[]
     message,result=modifyFilesNewGroup(version, group,project_name)
     if result == False:
-        errors.append([message, True])
+        logging.error(message)
+        errors.append([global_error, True])
 
     # Crea directorios y archivos dentro para un nuevo grupo
     message, result = createDirectoriesNewGroup(version, group, project_name)
     
     # Si falla al modificar directorios se agrega a arreglo
     if result == False:
-        errors.append([message, True])
+        logging.error(message)
+        errors.append([global_error, True])
 
 
     try:
-        with open('springlabs_django.json') as file:
+        with open(CONFIG_JSON) as file:
             data = json.load(file)
     except Exception as e:
-        message = "Ocurrio un error interno al actualizar archivo springlabs_django.json"
-        errors.append([message, True])
+        message = f"An internal error occurred while updating the file {CONFIG_JSON}"
+        logging.error(message)
+        errors.append([global_error, True])
     else:
         groupcap=group.capitalize()
         changename=f"ExampleDjango{groupcap}"
@@ -315,11 +359,12 @@ def createGroup(version, group, project_name):
                     obj["graph_list"]=[]
                 obj["graph_list"].append(f"{changename}Queries")
         try:
-            with open("springlabs_django.json", "w") as file:
+            with open(CONFIG_JSON, "w") as file:
                 file.write(json.dumps(data))
         except:
-            message = "Ocurrio un error interno al actualizar archivo springlabs_django.json"
-            errors.append([message, True])
+            message = f"An internal error occurred while updating the file {CONFIG_JSON}"
+            logging.error(message)
+            errors.append([global_error, True])
     for error in errors:
         if error[1] == True:
             message, result = reverseChanges(project_name=project_name)
@@ -327,4 +372,5 @@ def createGroup(version, group, project_name):
             os.remove(project_name + ".zip")
             os.chdir(project_name)
             return error[0], False
+    deleteBackup(project_name=project_name)
     return "OK", True
